@@ -8,10 +8,29 @@ use LWP::UserAgent;
 use JSON qw( decode_json );
 use Params::Validate qw( validate SCALAR );
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use constant URL => 'https://www.google.com/recaptcha/api/siteverify';
 
+my $IPv4_re = "((25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})[.](25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})[.](25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})[.](25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2}))";
+my $G       = "[0-9a-fA-F]{1,4}";
+
+my @tail = ( ":",
+	"(:($G)?|$IPv4_re)",
+    ":($IPv4_re|$G(:$G)?|)",
+    "(:$IPv4_re|:$G(:$IPv4_re|(:$G){0,2})|:)",
+	"((:$G){0,2}(:$IPv4_re|(:$G){1,2})|:)",
+	"((:$G){0,3}(:$IPv4_re|(:$G){1,2})|:)",
+	"((:$G){0,4}(:$IPv4_re|(:$G){1,2})|:)"
+);
+
+my $IPv6_re = $G;
+
+$IPv6_re = "$G:($IPv6_re|$_)" for @tail;
+$IPv6_re = qq/:(:$G){0,5}((:$G){1,2}|:$IPv4_re)|$IPv6_re/;
+$IPv6_re =~ s/\(/(?:/g;
+$IPv6_re = qr/$IPv6_re/;
+
 sub new {
     my $class = shift;
     my $self  = validate( @_, {
@@ -43,8 +62,8 @@ sub siteverify {
             type      => SCALAR,
             optional  => 1,
             callbacks => {
-                'is a remote ipv4 address' =>
-                    sub { $_[0] =~ /^((25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$/ }
+                'is a remote ipv4 or ipv6 address' =>
+                    sub { $_[0] =~ /^$IPv4_re$/ || $_[0] =~ /^$IPv6_re$/ }
             },
         },
     } );
@@ -121,19 +140,19 @@ Required. Form data containing g_captcha_response.
 
 B<remoteip>
 
-Optional. User's ip address.
+Optional. User's ip address. Both IPv4 and IPv6 is supported.
 
 =head2 Errors
 
 B<Error code reference:>
 
-missing-input-secret    I<The secret parameter is missing.>
+missing-input-secret    - I<The secret parameter is missing.>
 
-invalid-input-secret    I<The secret parameter is invalid or malformed.>
+invalid-input-secret    - I<The secret parameter is invalid or malformed.>
 
-missing-input-response	I<The response parameter is missing.>
+missing-input-response  - I<The response parameter is missing.>
 
-invalid-input-response	I<The response parameter is invalid or malformed.>
+invalid-input-response  - I<The response parameter is invalid or malformed.>
 
 =head1 Git repo
 
@@ -141,7 +160,7 @@ L<https://bitbucket.org/tcorkran/google-recaptcha>
 
 =head1 VERSION
 
-0.04
+0.05
 
 =head1 AUTHOR
 
